@@ -104,8 +104,9 @@ class PythonRunner(Runner):
         files[filename] = code
         return files
 
-    def make_from_package(self, dirpath, dirname):
+    def make_from_package(self, dirpath, dirname_):
         files = dict()
+        dirname = os.path.normpath(dirname_)
         if dirpath in self.imports:
             return files
         if os.path.exists(dirpath):
@@ -128,10 +129,10 @@ class PythonRunner(Runner):
 class PythonCLI(CLI):
 
     def __init__(self, compiler=None):
-        super(PythonCLI, self).__init__('Python', compiler, False)
+        super(PythonCLI, self).__init__('Python', compiler, False, False)
 
     def get_runner(self, args, options):
-        return PythonRunner(args.language, args.compiler, args.save, args.encoding, args.retry, args.retry_wait, False)
+        return PythonRunner(args.language, args.compiler, args.save, args.encoding, args.retry, args.retry_wait)
 
 
 def python(compiler=None):
